//
// Copyright 2002-2005 Aspose Pty Ltd. All Rights Reserved.
//
// This file is part of Aspose.Pdf.Kit for Java. The source code in this file
// is only intended as a supplement to the documentation, and is provided
// "as is", without warranty of any kind, either expressed or implied.
//
package samples.viewer;

import java.awt.Color;
import java.awt.BorderLayout;
import java.awt.Container;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.print.PageFormat;
import java.awt.print.Paper;
import java.awt.print.PrinterException;
import java.awt.print.PrinterJob;
import java.net.URL;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextField;
import javax.swing.JToolBar;
import javax.swing.UIManager;
import javax.swing.WindowConstants;
import java.io.File;

import com.aspose.pdf.kit.PdfViewer;
import com.aspose.pdf.kit.PdfViewerException;
import com.aspose.pdf.kit.PdfViewerFontException;
import com.aspose.pdf.kit.PdfViewerSecurityException;

/**
 * <p>A simple example to display Pdf files - The SimpleViewer
 * example shows all the PdfViewer lib functions.
 * </p>
 * <p>Copyright: 2002-2005 . All Rights Reserved.</p>
 * <p>Company: Aspose Pty Ltd</p>
 * 
 */
 
public class SimplePdfViewer extends JFrame
{
	private static final long serialVersionUID = 100020050918L;
		
	/**
	 * the title of this application.
	 */
	private String simplePdfViewerTitle = "PdfViewer";
	
	/**
	 * the function point of the PdfViewer Lib.
	 */
	private PdfViewer pdfviewer;
	
	/**
	 * the path of current pdf file.
	 */
	private String currentPdfFilePath = null;

	/** 
	 * the current page number of the current Pdf file.
	 * The first page is 1.
	 */
	private int currentPage = 1;

	/** 
	 * contentPane of this JFrame.
	 */
	protected Container contentPane = getContentPane();
	
	/** 
	 * the flag of print task.
	 */
	protected static int printingLocks = 0;
	
	private final JLabel pageLabel = new JLabel("Page ");

	private JTextField currentPageText = new JTextField(4);
	
	private JLabel pageOfLabel = new JLabel("of");	
	
	protected JComboBox scalingBox;

	private final int defaultSelection = 0;

	/**
	 * page scale factor, 1 = 100%.
	 */
	protected float scaleFactor = 1;

	private JScrollPane displayScrollPane;

	protected String[] scaleValues = {
			"Window",
			"Height",
			"Width",
			"25", "50", "75", 
			"100", "125", "150", 
			"200", "250", "500" };

	/** 
	 * scale values as floats.
	 */
	protected float[] scaleFloatValues = { 
			1.0f, 1.0f, 1.0f, .25f, .5f, .75f, 1.0f,
			1.25f, 1.5f, 2.0f, 2.5f, 5.0f };

	/** 
	 * the edge of page.
	 */
	private final int inset = 25;
	
	/**
	 * The constructor of the SimplePdfViewer object.
	 */
	public SimplePdfViewer()
	{
		pdfviewer = new PdfViewer();
		
		//shows the Pdf GUI.
		initializeViewer();
	}

	/**
	 * The constructor of the SimplePdfViewer object.
	 * 
	 * @param name String the full file path.
	 */
	public SimplePdfViewer(String name)
	{

		pdfviewer = new PdfViewer();

		currentPdfFilePath = name;

		try
		{
			//opens a pdf file.
			pdfviewer.openPdfFile(currentPdfFilePath);	
			
			//decodes the pdf page.
			pdfviewer.decodePage(currentPage);
			
			//Initialises the initial scale factor of the specific Pdf page number the first 1 = 100% scale factor, the second 1 is the Pdf page number.
			pdfviewer.setPdfPageParameters(1, 1); 
		}
		catch (PdfViewerFontException ex)
		{
			System.out.println(ex);
		}
		catch (PdfViewerSecurityException ex)
		{
			System.out.println(ex);
		}		
		catch (PdfViewerException ex)
		{
			System.out.println(ex);
		}
		catch (Exception ex)
		{
			System.out.println(ex);
		}

		//shows the Pdf GUI.
		initializeViewer();
		
		currentPageText.setText(currentPage + "");
		pageOfLabel.setText("of " + pdfviewer.getPdfFilePageCount());
	}

	/**
	 * opens a pdf file.
	 */
	private void selectFile()
	{
		if (printingLocks != 0) { return; }
		
		JFileChooser open = new JFileChooser(".");
		open.setFileSelectionMode(JFileChooser.FILES_ONLY);

		String[] pdf = new String[] { "pdf" };
		open.addChoosableFileFilter(new PdfFileFilter(pdf, "Pdf (*.pdf)"));

		int resultOfFileSelect = JFileChooser.ERROR_OPTION;
		while (resultOfFileSelect == JFileChooser.ERROR_OPTION)
		{
			resultOfFileSelect = open.showOpenDialog(this);

			if (resultOfFileSelect == JFileChooser.ERROR_OPTION)
				System.err.println("JFileChooser error.");

			if (resultOfFileSelect == JFileChooser.APPROVE_OPTION)
			{
				currentPdfFilePath = open.getSelectedFile().getAbsolutePath();

				currentPage = 1;
				try
				{
					//closes the current Pdf file before opening another.
					pdfviewer.closePdfFile();

					//opens a Pdf file and reads its internal details.
					pdfviewer.openPdfFile(currentPdfFilePath);

					//decodes the page.
					pdfviewer.decodePage(currentPage);
					pdfviewer.setPdfPageParameters(1, 1);
					
					pdfviewer.invalidate();

				}
				catch (PdfViewerFontException ex)
				{
					System.out.println(ex);
				}
				catch (PdfViewerSecurityException ex)
				{
					System.out.println(ex);
				}		
				catch (PdfViewerException ex)
				{
					System.out.println(ex);
				}
				catch (Exception ex)
				{
					System.out.println(ex);
				}

				//shows the page number.
				currentPageText.setText(currentPage + "");
				pageOfLabel.setText("of " + pdfviewer.getPdfFilePageCount());

				setTitle(simplePdfViewerTitle + " - " + currentPdfFilePath);

				repaint();
			}
		}
	}

	/**
	 * initializes the pdf viewer and its components.
	 */
	private void initializeViewer()
	{
		setDefaultCloseOperation(WindowConstants.EXIT_ON_CLOSE);
		contentPane = getContentPane();
		contentPane.setLayout(new BorderLayout());

		//open button.
		JButton open = initOpenButton();

		//print button.
		JButton print = initPrintButton();
		
		scalingBox = new JComboBox(scaleValues);
		scalingBox.setBackground(Color.white);
		scalingBox.setEditable(true);
		scalingBox.setPreferredSize(new Dimension(85, 25));
		scalingBox.setSelectedIndex(defaultSelection);
		
		scalingBox.addActionListener(new zoomAdapter(this));
		
		JPanel pageChanger = initViewPanel();

		JToolBar topBar = new JToolBar();
		topBar.setLayout(new FlowLayout(FlowLayout.LEADING, 0, 0));
		topBar.add(open);
		topBar.add(print);
		topBar.add(scalingBox);

		topBar.add(pageChanger);

		JPanel top = new JPanel();
		top.setLayout(new BorderLayout());

		//creates the menu bar.
		JMenuBar currentMenu = new JMenuBar();
		top.add(currentMenu, BorderLayout.NORTH);

		createMenu(currentMenu);

		top.add(topBar, BorderLayout.CENTER);

		contentPane.add(top, BorderLayout.NORTH);
		
		//initializes the Pdf show.
		displayScrollPane = pdfviewer.showPdf();
		contentPane.add(displayScrollPane, BorderLayout.CENTER);

		pack();

		Dimension screen = Toolkit.getDefaultToolkit().getScreenSize();
		setSize(screen.width * 3 / 4, screen.height * 3 / 4);
		setTitle(simplePdfViewerTitle);

		setLocationRelativeTo(null);
		setVisible(true);
	}	

	/**
	 * Creates items on drop down menus.
	 */
	protected void createMenu(JMenuBar currentMenu)
	{
		JMenu fileMenuList = new JMenu("File");
		
		//Open item
		JMenuItem openItem = new JMenuItem("Open");
		openItem.setToolTipText("Open a Pdf file");
		openItem.addActionListener(new openFileAdapter(this));
		fileMenuList.add(openItem);
		
		//Print item
		JMenuItem printItem = new JMenuItem("Print");
		printItem.setToolTipText("Print file");
		printItem.addActionListener(new printAdapter(this));
		fileMenuList.add(printItem);
		
		//Exit item
		JMenuItem exitItem = new JMenuItem("Exit");
		exitItem.setToolTipText("exit application");
		exitItem.addActionListener(new exitAdapter(this));
		fileMenuList.add(exitItem);

		//Menu add the file Menu list.
		currentMenu.add(fileMenuList);

		
		JMenu viewList = new JMenu("View");

		//First Page item
		JMenuItem firstPageItem = new JMenuItem("First Page");
		firstPageItem.setToolTipText("Show First Page");
		firstPageItem.addActionListener(new goFirstAdapter(this));
		viewList.add(firstPageItem);

		//Backward Five Page item
		JMenuItem backwardFivePageItem = new JMenuItem("Back five Page");
		backwardFivePageItem.setToolTipText("Show Backward five Page");
		backwardFivePageItem.addActionListener(new goBackFiveAdapter(this));
		viewList.add(backwardFivePageItem);

		//Backward One Page item
		JMenuItem backwardOenPageItem = new JMenuItem("Back one Page");
		backwardOenPageItem.setToolTipText("Show Backward one Page");
		backwardOenPageItem.addActionListener(new goBackOneAdapter(this));
		viewList.add(backwardOenPageItem);

		//Forward One Page item
		JMenuItem forwardOenPageItem = new JMenuItem("Next one Page");
		forwardOenPageItem.setToolTipText("Show next one Page");
		forwardOenPageItem.addActionListener(new goForwardOneAdapter(this));
		viewList.add(forwardOenPageItem);

		//Forward Five Page item
		JMenuItem forwardFivePageItem = new JMenuItem("Next five Page");
		forwardFivePageItem.setToolTipText("Show next Five Page");
		forwardFivePageItem.addActionListener(new goForwardFiveAdapter(this));
		viewList.add(forwardFivePageItem);

		//Last Page item
		JMenuItem lastPageItem = new JMenuItem("Last Page");
		lastPageItem.setToolTipText("Show last Page");
		lastPageItem.addActionListener(new goLastAdapter(this));
		viewList.add(lastPageItem);

		
		currentMenu.add(viewList);
	}

	/**
	 * Initializes the open button with listener.
	 */
	private JButton initOpenButton()
	{
		JButton open = new JButton();
		URL openImage = getClass().getResource("./img/open.gif");
		open.setIcon(new ImageIcon(openImage));
		open.setText("Open");
		open.setToolTipText("Open a file");
		open.setBorderPainted(false);
		open.addActionListener(new openFileAdapter(this));

		return open;
	}

	/**
	 * Initializes the print button with listener.
	 */
	private JButton initPrintButton()
	{
		JButton print = new JButton();
		URL printImage = getClass().getResource("./img/print.gif");
		print.setIcon(new ImageIcon(printImage));
		print.setText("Print");
		print.setToolTipText("Print a file");
		print.setBorderPainted(false);
		print.addActionListener(new printAdapter(this));

		return print;
	}

	/**
	 * Handles printing function,and uses the Java print function to print pdf file.
	 */
	protected void printPdfFile()
	{
		if (printingLocks != 0) { return; }

		//adds a print lock to ensure only a pdf file to print.
		printingLocks++;
		
		//prints in thread to improve background printing.		 
		Thread workerThread = new Thread() {
			public void run()
			{
				boolean canceled = false;
				try
				{
					//sets the default print scale.
					pdfviewer.enableScalePrint(false);

					//gets a printjob object.
					PrinterJob printJob = PrinterJob.getPrinterJob();
					PageFormat pf = printJob.defaultPage();

					//sets PageOrientation to best use page layout.
					int orientation = pdfviewer.getPdfWidth() < pdfviewer.getPdfHeight() ? PageFormat.PORTRAIT : PageFormat.LANDSCAPE;
					pf.setOrientation(orientation);

					Paper paper = new Paper();
					paper.setSize(595, 842);
					paper.setImageableArea(43, 43, 509, 756);

					if (!canceled)
					{
						pf.setPaper(paper);
						printJob.setPrintable(pdfviewer, pf);

						boolean printFile = printJob.printDialog();
						if (printFile)
						{
							printJob.print();
						}
					}
				}
				catch (PrinterException ex)
				{
					JOptionPane.showMessageDialog(contentPane, ex.getMessage() + " " + ex + " " + " " + ex.getCause());
				}
				catch (Exception ex)
				{
					System.out.println(ex);
					JOptionPane.showMessageDialog(contentPane, "Exception " + ex);
				}
				catch (Error err)
				{
					JOptionPane.showMessageDialog(contentPane, "Error " + err);
				}

				if (!canceled && !pdfviewer.isPrintSuccess())
					JOptionPane.showMessageDialog(contentPane, "Problems encountered\n " + pdfviewer.getPrintFailureMessage() + "\n");

				printingLocks--;

				// cleans up the GUI.
				pdfviewer.invalidate();
				pdfviewer.updateUI();
				repaint();

				if (!canceled)
					JOptionPane.showMessageDialog(contentPane, "finished printing");
			}
		};

		//starts printing in background.
		workerThread.start();
	}
	
	/**
	 * Initializes the page display and changer panel and return it.
	 */
	private JPanel initViewPanel()
	{
		JPanel currentBar = new JPanel();
		currentBar.setLayout(new FlowLayout(FlowLayout.LEADING, 0, 0));

		//back to the first page.
		JButton startPageButton = new JButton();
		startPageButton.setPreferredSize(new Dimension(45, 28));
		startPageButton.setBorderPainted(false);
		URL startImage = getClass().getResource("./img/startPage.gif");
		startPageButton.setIcon(new ImageIcon(startImage));
		startPageButton.setToolTipText("Go to first page");
		currentBar.add(startPageButton);
		startPageButton.addActionListener(new goFirstAdapter(this));

		//back to five pages.
		JButton backFivePageButton = new JButton();
		backFivePageButton.setPreferredSize(new Dimension(45, 28));
		backFivePageButton.setBorderPainted(false);
		URL fbackImage = getClass().getResource("./img/backFivePage.gif");
		backFivePageButton.setIcon(new ImageIcon(fbackImage));
		backFivePageButton.setToolTipText("Back 5 pages");
		currentBar.add(backFivePageButton);
		backFivePageButton.addActionListener(new goBackFiveAdapter(this));

		//back one page.
		JButton backOnePageButton = new JButton();
		backOnePageButton.setPreferredSize(new Dimension(45, 28));
		backOnePageButton.setBorderPainted(false);
		URL backImage = getClass().getResource("./img/backOnePage.gif");
		backOnePageButton.setIcon(new ImageIcon(backImage));
		backOnePageButton.setToolTipText("Back 1 page");
		currentBar.add(backOnePageButton);
		backOnePageButton.addActionListener(new goBackOneAdapter(this));

		currentPageText.setEditable(true);
		currentPageText.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent a)
			{
				String value = (String) currentPageText.getText().trim();
				int newPageNumber;
				try
				{
					newPageNumber = Integer.parseInt(value);
					if ((newPageNumber > pdfviewer.getPdfFilePageCount()) | (newPageNumber < 1)) 
						{ 
							return; 
						}

					currentPage = newPageNumber;
					try
					{
						pdfviewer.decodePage(currentPage);
						pdfviewer.invalidate();
						repaint();
					}
					catch (Exception ex)
					{
						System.err.println("page number entered.");
						System.out.println(ex);
					}

				}
				catch (Exception ex)
				{
					JOptionPane.showMessageDialog(null,">" + value + "< is Not a valid page number.\nPlease enter a number between 1 and " + pdfviewer.getPdfFilePageCount());
					return;
				}
			}
		});

		//page count.
		currentBar.add(pageLabel);
		currentBar.add(new JPanel());
		currentBar.add(currentPageText);
		currentBar.add(new JPanel());
		currentBar.add(pageOfLabel);

		//forward one page.
		JButton forwardOnePageButton = new JButton();
		forwardOnePageButton.setPreferredSize(new Dimension(45, 28));
		forwardOnePageButton.setBorderPainted(false);
		URL fowardImage = getClass().getResource("./img/forwardOnePage.gif");
		forwardOnePageButton.setIcon(new ImageIcon(fowardImage));
		forwardOnePageButton.setToolTipText("Forward 1 page");
		currentBar.add(forwardOnePageButton);
		forwardOnePageButton.addActionListener(new goForwardOneAdapter(this));

		//forward five page.
		JButton forwardFivePageButton = new JButton();
		forwardFivePageButton.setPreferredSize(new Dimension(45, 28));
		forwardFivePageButton.setBorderPainted(false);
		URL ffowardImage = getClass().getResource("./img/forwardFivePage.gif");
		forwardFivePageButton.setIcon(new ImageIcon(ffowardImage));
		forwardFivePageButton.setToolTipText("Forward 5 pages");
		currentBar.add(forwardFivePageButton);
		forwardFivePageButton.addActionListener(new goForwardFiveAdapter(this));

		//goto the last page.
		JButton lastPageButton = new JButton();
		lastPageButton.setPreferredSize(new Dimension(45, 28));
		lastPageButton.setBorderPainted(false);
		URL endImage = getClass().getResource("./img/lastPage.gif");
		lastPageButton.setIcon(new ImageIcon(endImage));
		lastPageButton.setToolTipText("Forward to last page");
		currentBar.add(lastPageButton);
		lastPageButton.addActionListener(new goLastAdapter(this));

		return currentBar;
	}

	/**
	 * Zooms the current page and the maximum is 500.
	 */
	private void changePageSize()
	{
		if (pdfviewer != null)
		{
			int index = scalingBox.getSelectedIndex();
			if (index == -1)
			{
				String numberString = (String) scalingBox.getSelectedItem();

				float zoomFactor = -1;
				if ((numberString != null) && (numberString.length() > 0))
				{
					try
					{
						zoomFactor = Float.parseFloat(numberString);
					}
					catch (Exception ex)
					{
						zoomFactor = -1;
						int length = numberString.length();
						int i = 0;
						while (i < length)
						{
							char c = numberString.charAt(i);
							if (((c >= '0') && (c <= '9')) | (c == '.'))
								i++;
							else
								break;
						}

						if (i > 0)
							numberString = numberString.substring(0, i);

						if (zoomFactor == -1)
						{
							try
							{
								zoomFactor = Float.parseFloat(numberString);
							}
							catch (Exception e1)
							{
								zoomFactor = -1;
							}
						}
					}
					if (zoomFactor > 500)
					{
						zoomFactor = 500;
					}
				}

				if (zoomFactor == -1)
				{
					index = defaultSelection;
					scalingBox.setSelectedItem(scalingBox.getItemAt(index));
				}
				else
				{
					scaleFactor = zoomFactor / 100;
					scalingBox.setSelectedItem(zoomFactor + "");
				}
			}
			if (index != -1)
			{
				if (index < 3)
				{
					int cw, ch;
					cw = pdfviewer.getCropBoxWidth(currentPage);
					ch = pdfviewer.getCropBoxHeight(currentPage);

					float width = displayScrollPane.getViewport().getWidth() - inset * 2;
					float height = displayScrollPane.getViewport().getHeight() - inset * 2;

					float xfactor = 0, yfactor = 0;
					xfactor = width / cw;
					yfactor = height / ch;

					if (index == 0)
					{
						if (xfactor < yfactor)
							scaleFactor = xfactor;
						else
							scaleFactor = yfactor;
					}
					else if (index == 1)
						scaleFactor = yfactor;
					else if (index == 2)
						scaleFactor = xfactor;
				}
				else
				{
					scaleFactor = scaleFloatValues[index];
				}
			}

			//checks for 0 to avoid error and replaces with 1.
			if ((pdfviewer.getCropBoxHeight(currentPage) * scaleFactor < 100) &&(pdfviewer.getCropBoxWidth(currentPage) * scaleFactor < 100))
			{
				scaleFactor = 1;
				scalingBox.setSelectedItem("100");
			}

			if (pdfviewer != null)
				pdfviewer.setPdfPageParameters(scaleFactor, currentPage);

			pdfviewer.invalidate();
			displayScrollPane.repaint();
			validate();
		}
	}

	/**
	 * goes to the first page.
	 */	
	private void gotoFirstPage()
	{
		if (currentPdfFilePath != null && currentPage != 1)
		{
			currentPage = 1;
			try
			{
				pdfviewer.decodePage(currentPage);
				pdfviewer.invalidate();
				repaint();
			}
			catch (Exception ex)
			{
				System.err.println("back to page 1");
				System.out.println(ex);
			}

			//shows the page number.
			currentPageText.setText(currentPage + "");
		}
	}

	/**
	 * goes back five pages.
	 */	
	private void gotoBackwardFivePage()
	{
		if (currentPdfFilePath != null && currentPage > 5)
		{
			currentPage = currentPage - 5;
			try
			{
				pdfviewer.decodePage(currentPage);
				pdfviewer.invalidate();
				repaint();
			}
			catch (Exception ex)
			{
				System.err.println("back 5 pages");
				System.out.println(ex);
			}

			//shows the page number.
			currentPageText.setText(currentPage + "");
		}
	}

	/**
	 * goes back one page.
	 */	
	private void gotoBackwardOnePage()
	{
		if (currentPdfFilePath != null && currentPage > 1)
		{
			currentPage -= 1;
			try
			{
				pdfviewer.decodePage(currentPage);
				pdfviewer.invalidate();
				repaint();
			}
			catch (Exception ex)
			{
				System.err.println("back 1 page");
				System.out.println(ex);
			}

			//shows the page number.
			currentPageText.setText(currentPage + "");
		}
	}

	/**
	 * goes forward one page.
	 */	
	private void gotoForwardOnePage()
	{
		if (currentPdfFilePath != null && currentPage < pdfviewer.getPdfFilePageCount())
		{
			currentPage += 1;
			try
			{
				pdfviewer.decodePage(currentPage);
				pdfviewer.invalidate();
				repaint();
			}
			catch (Exception ex)
			{
				System.err.println("forward 1 page");
				System.out.println(ex);
			}

			//shows the page number.
			currentPageText.setText(currentPage + "");
		}
	}

	/**
	 * goes forward  five pages.
	 */	
	private void gotoForwardFivePage()
	{
		if (currentPdfFilePath != null && currentPage < pdfviewer.getPdfFilePageCount() - 4)
		{
			currentPage = currentPage + 5;
			try
			{
				pdfviewer.decodePage(currentPage);
				pdfviewer.invalidate();
				repaint();
			}
			catch (Exception ex)
			{
				System.err.println("forward 5 pages");
				System.out.println(ex);
			}

			//shows the page number.
			currentPageText.setText(currentPage + "");
		}
	}

	/**
	 * goes to the last page.
	 */	
	private void gotoLastPage()
	{
		if (currentPdfFilePath != null && currentPage < pdfviewer.getPdfFilePageCount())
		{
			currentPage = pdfviewer.getPdfFilePageCount();
			try
			{
				pdfviewer.decodePage(currentPage);
				pdfviewer.invalidate();
				repaint();
			}
			catch (Exception ex)
			{
				System.err.println("forward to last page");
				System.out.println(ex);
			}

			//shows the page number.
			currentPageText.setText(currentPage + "");
		}
	}
	
	class zoomAdapter implements ActionListener {
	    SimplePdfViewer adaptee;
	    zoomAdapter(SimplePdfViewer adaptee)
	    {
	    	this.adaptee = adaptee;
	    }
	    public void actionPerformed(ActionEvent actionEvent) {	        
	    	adaptee.changePageSize();
		}
	}
	
	/**
	 * A inner class which open a pdf file. 
	 */
	class openFileAdapter implements ActionListener {
	    SimplePdfViewer adaptee;
	    openFileAdapter(SimplePdfViewer adaptee)
	    {
	    	this.adaptee = adaptee;
	    }
	    public void actionPerformed(ActionEvent actionEvent) {	        
	    	adaptee.selectFile();
		}
	}
	
	/**
	 * A inner class which print the pdf file. 
	 */
	class printAdapter implements ActionListener {
	    SimplePdfViewer adaptee;
	    printAdapter(SimplePdfViewer adaptee)
	    {
	    	this.adaptee = adaptee;
	    }
	    public void actionPerformed(ActionEvent actionEvent) {	        
	    	adaptee.printPdfFile();
		}
	}
	
	/**
	 * A inner class which exits the programs. 
	 */
	class exitAdapter implements ActionListener {
	    SimplePdfViewer adaptee;
	    exitAdapter(SimplePdfViewer adaptee)
	    {
	    	this.adaptee = adaptee;
	    }
	    public void actionPerformed(ActionEvent actionEvent) {	        
	    	adaptee.exit();
		}
	}
	
	/**
	 * A inner class which goes to the first page.
	 */
	class goFirstAdapter implements ActionListener {
	    SimplePdfViewer adaptee;
	    goFirstAdapter(SimplePdfViewer adaptee)
	    {
	    	this.adaptee = adaptee;
	    }
	    public void actionPerformed(ActionEvent actionEvent) {	        
	    	adaptee.gotoFirstPage();
		}
	}
	
	/**
	 * A inner class which goes back five pages.
	 */
	class goBackFiveAdapter implements ActionListener {
	    SimplePdfViewer adaptee;
	    goBackFiveAdapter(SimplePdfViewer adaptee)
	    {
	    	this.adaptee = adaptee;
	    }
	    public void actionPerformed(ActionEvent actionEvent) {	        
	    	adaptee.gotoBackwardFivePage();
		}
	}
	
	/**
	 * A inner class which goes back one page.
	 */
	class goBackOneAdapter implements ActionListener {
	    SimplePdfViewer adaptee;
	    goBackOneAdapter(SimplePdfViewer adaptee)
	    {
	    	this.adaptee = adaptee;
	    }
	    public void actionPerformed(ActionEvent actionEvent) {	        
	    	adaptee.gotoBackwardOnePage();
		}
	}
	
	/**
	 * A inner class which goes forward one page.
	 */
	class goForwardOneAdapter implements ActionListener {
	    SimplePdfViewer adaptee;
	    goForwardOneAdapter(SimplePdfViewer adaptee)
	    {
	    	this.adaptee = adaptee;
	    }
	    public void actionPerformed(ActionEvent actionEvent) {	        
	    	adaptee.gotoForwardOnePage();
		}
	}
	
	/**
	 * A inner class which goes forward five pages.
	 */
	class goForwardFiveAdapter implements ActionListener {
	    SimplePdfViewer adaptee;
	    goForwardFiveAdapter(SimplePdfViewer adaptee)
	    {
	    	this.adaptee = adaptee;
	    }
	    public void actionPerformed(ActionEvent actionEvent) {	        
	    	adaptee.gotoForwardFivePage();
		}
	}
	
	/**
	 * A inner class which goes to the last page.
	 */
	class goLastAdapter implements ActionListener {
	    SimplePdfViewer adaptee;
	    goLastAdapter(SimplePdfViewer adaptee)
	    {
	    	this.adaptee = adaptee;
	    }
	    public void actionPerformed(ActionEvent actionEvent) {	        
	    	adaptee.gotoLastPage();
		}
	}
	
	/**
	 * An inner class to provide filters for open dialog.
	 */
	class PdfFileFilter extends javax.swing.filechooser.FileFilter
	{
		private String[] extensions;
		private String description;
		private int items = 0;

		//sets file and descriptor.
		public PdfFileFilter(String[] extend, String desc)
		{
			items = extend.length;

			//sets as lower case list.
			extensions = new String[items];
			for (int i = 0; i < items; i++)
			{
				extensions[i] = extend[i].toLowerCase();
				description = desc;
			}
		}

		final public String getDescription()
		{
			return description;
		}

		final public boolean accept(File files)
		{
			boolean accept = false;
			if (files.isDirectory())
				accept = true;
			else
			{
				String file_name = files.getName().toLowerCase();
				for (int i = 0; i < items; i++)
				{
					if (file_name.endsWith(extensions[i]))
						accept = true;
				}
			}
			return accept;
		}
	}
	
	/**
	 * exits the application.
	 */	
	private void exit()
	{
		pdfviewer.closePdfFile();
		System.exit(1);
	}

	/** 
	 * main function.
	 */
	public static void main(String[] args)
	{
		//if you got a license, uncomment following lines
//		License lic  = new License();
//		try 
//		{
//			lic.setLicense(new FileInputStream(new File("Aspose.Pdf.Kit.Java.Ent.lic")));
//		} catch (Exception e) {
//			System.out.println(e.getMessage());
//		}
		
		String testPdfFilePath = "./text.pdf";

		try
		{
			UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
		}
		catch (Exception ex)
		{
			System.out.println(ex);
		}
		
		SimplePdfViewer current = null;
		
		//checks the file exist or not.
		File testFile = new File(testPdfFilePath);
		if (testFile.exists() == false)
			current = new SimplePdfViewer();
		else
			current = new SimplePdfViewer(testPdfFilePath);	
	}	
}
